<template>
  <el-dialog
    v-diadrag
    width="60%"
    title="抽检规则列表"
    top="5vh"
    :visible.sync="innerVisible"
    append-to-body
    @close="$emit('update:currshowlist', false)"
    :show="currshowlist"
    class="orderspotcheckrule-dialog"
  >
    <ttable
      :table="table"
      @handleSelectionChange="handleSelectionChange"
      :uploadInfo="uploadInfo"
      :prelang="prelang"
      :options="options"
      :bottomOffset="350"
      :ajaxFun="ajaxFun"
      :paramObj="paramObj"
      ref="orderSpotCheckRuleTable"
    >
      <template #toolbar></template>
    </ttable>

    <div slot="footer" class="dialog-footer">
      <el-button @click="innerVisible = false">取 消</el-button>
      <el-button type="primary" @click="saveSelectRow">确 定</el-button>
    </div>
  </el-dialog>
</template>
<script>
import { fetchListSamplingRule } from '@/api/quality/samplingrule'
import { batchSaveMoSamplingRule } from '@/api/plan/mosamplingrule'
import ttable from '@/views/common/ztt-table'
import { remote } from '@/api/admin/dict'

export default {
  props: {
    currshowlist: {
      type: Boolean,
      default: false
    },
    paramObj: {
      type: Object,
      default: () => {
        return {}
      }
    },
    moId: {
      type: Number,
      default: 0
    },
    moRoutingOperationId: {
      type: Number,
      default: 0
    },
    moRoutingOperationName: {
      type: String,
      default: null
    }
  },
  data() {
    return {
      ajaxFun: fetchListSamplingRule,
      innerVisible: false,
      multipleSelection: [],
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      prelang: 'orderSpotCheckRule',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: true, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'id', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          // 规则编号
          {
            minWidth: '30',
            prop: 'ruleNo',
            label: '规则编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 规则名称
          {
            minWidth: '120',
            prop: 'ruleName',
            label: '规则名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 抽检工序
          {
            minWidth: '120',
            prop: 'samplingOperationName',
            label: '抽检工序',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 追溯工序
          {
            minWidth: '120',
            prop: 'retrospectOperationName',
            label: '追溯工序',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 检测类型
          {
            minWidth: '120',
            prop: 'applyType',
            label: '检测类型',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            optList: () => {
              return this.getReportTypeOptions()
            },
            formatter: (row, column, cellValue) => {
              this.reportTypeOptions.forEach((obj) => {
                if (obj.value === cellValue) {
                  cellValue = obj.label
                }
              })
              return cellValue
            }
          },
          // 抽检比例
          {
            minWidth: '120',
            prop: 'measurement',
            label: '抽检比例',
            sort: true,
            isTrue: true,
            isSearch: false,
            searchInfoType: 'text',
            formatter: (row, column, cellValue) => {
              const formatVal =
                row.samplingNumerator + '/' + row.samplingDenominator
              return formatVal
            }
          },
          // 抽检位置
          {
            minWidth: '120',
            prop: 'samplingPosition',
            label: '抽检位置',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          }
        ],
        reportTypeOptions: []
      },
      addOrUpdateVisible: false
    }
  },
  components: {
    ttable
  },
  methods: {
    saveSelectRow() {
      const reqList = []
      if (this.multipleSelection.length > 0) {
        let flag = true
        this.multipleSelection.forEach((item) => {
          if (item.samplingOperationName != this.moRoutingOperationName) {
            flag = false
          }
          reqList.push({
            moId: this.moId,
            moRoutingOperationId: this.moRoutingOperationId,
            samplingRuleId: item.id
          })
        })
        if (flag) {
          batchSaveMoSamplingRule(reqList)
            .then((response) => {
              this.$emit('refreshSpotCheckRuleList')
              this.innerVisible = false
            })
            .catch(() => {
              this.innerVisible = false
            })
        } else {
          this.$message.error('当前工序与抽检工序不一致')
        }
      } else {
        this.$message.error('请先选择抽检规则')
      }
    },
    handleSelectionChange(val) {
      // 多行选中
      this.multipleSelection = val
    },
    getData() {
      if (this.$refs.orderSpotCheckRuleTable !== undefined) {
        this.$refs.orderSpotCheckRuleTable.getDataList()
      }
    },
    initReportTypeSelect() {
      remote('apply_report_type').then((response) => {
        const code = response.data.code
        if (code === 0) {
          const _data = response.data.data
          this.reportTypeOptions = _data
        }
      })
    },
    getReportTypeOptions() {
      return this.reportTypeOptions
    }
  },
  watch: {
    currshowlist() {
      this.innerVisible = this.currshowlist
      if (this.currshowlist) {
        this.$nextTick(() => {
          this.getData()
        })
      }
    }
  },
  mounted() {
    this.initReportTypeSelect()
  }
}
</script>
<style>
.orderspotcheckrule-dialog .el-dialog__header {
  padding: 10px 20px 10px;
}
.orderspotcheckrule-dialog .el-dialog__header .el-dialog__headerbtn {
  top: 10px;
}
.orderspotcheckrule-dialog .el-dialog__body {
  padding: 5px 20px;
}

.orderspotcheckrule-dialog .el-dialog__footer {
  padding: 5px 20px 10px;
}

.orderspotcheckrule-dialog .el-dialog__body .avue-crud__pagination {
  margin-top: 0px;
  margin-bottom: 5px;
}
</style>
